Build class

Information about the current Android build, extracted from system properties.

Constructors

Build.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager})
Constructs Build without creating the associated native object.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeon_binaryMessenger BinaryMessenger?
Sends and receives binary data across the Flutter platform barrier.
finalinherited
pigeon_instanceManager → PigeonInstanceManager
Maintains instances stored to communicate with native language objects.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pigeon_copy() Build
Instantiates and returns a functionally identical object to oneself.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getSdkVersion({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager}) Future<int>
Returns the current Android SDK version that is running on the device.
pigeon_setUpMessageHandlers({bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Build pigeon_newInstance()?}) → void