GeocodeListener class
A listener for asynchronous geocoding results. Only one of the methods will ever be invoked per geocoding attempt. There are no guarantees on how long it will take for a method to be invoked, nor any guarantees on the format or availability of error information.
See https://developer.android.com/reference/android/location/Geocoder.GeocodeListener.
Constructors
-
GeocodeListener({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required void onError(GeocodeListener pigeon_instance, String? errorMessage), required void onGeocode(GeocodeListener pigeon_instance, List<
Address?> addresses)}) -
factory
-
GeocodeListener.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required void onError(GeocodeListener pigeon_instance, String? errorMessage), required void onGeocode(GeocodeListener pigeon_instance, List<
Address?> addresses)}) - Constructs GeocodeListener without creating the associated native object.
-
GeocodeListener.pigeon_new({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required void onError(GeocodeListener pigeon_instance, String? errorMessage), required void onGeocode(GeocodeListener pigeon_instance, List<
Address?> addresses)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onError → void Function(GeocodeListener pigeon_instance, String? errorMessage)
-
Callback method.
final
-
onGeocode
→ void Function(GeocodeListener pigeon_instance, List<
Address?> addresses) -
Callback method.
final
- pigeon_binaryMessenger → BinaryMessenger?
-
Sends and receives binary data across the Flutter platform barrier.
finalinherited
- pigeon_instanceManager → PigeonInstanceManager
-
Maintains instances stored to communicate with native language objects.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pigeon_copy(
) → GeocodeListener - Instantiates and returns a functionally identical object to oneself.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pigeon_setUpMessageHandlers(
{bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, void onError(GeocodeListener pigeon_instance, String? errorMessage)?, void onGeocode(GeocodeListener pigeon_instance, List< Address?> addresses)?}) → void