Geocoder class

A class for handling geocoding and reverse geocoding.

See https://developer.android.com/reference/android/location/Geocoder.

Constructors

Geocoder({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Locale? locale})
Creates a Geocoder.
factory
Geocoder.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager})
Constructs Geocoder without creating the associated native object.
Geocoder.pigeon_new({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Locale? locale})
Creates a Geocoder.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeon_binaryMessenger BinaryMessenger?
Sends and receives binary data across the Flutter platform barrier.
finalinherited
pigeon_instanceManager → PigeonInstanceManager
Maintains instances stored to communicate with native language objects.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFromLocation(double latitude, double longitude, int maxResults, GeocodeListener listener) Future<void>
Provides an array of Addresses that attempt to describe the area immediately surrounding the given latitude and longitude.
getFromLocationName(String locationName, int maxResults, GeocodeListener listener, GeographicBounds? bounds) Future<void>
Returns an array of Addresses that attempt to describe the named location, which may be a place name such as "Dalvik, Iceland", an address such as "1600 Amphitheatre Parkway, Mountain View, CA", an airport code such as "SFO", and so forth.
getFromLocationNamePreAndroidApi33(String locationName, int maxResults, GeographicBounds? bounds) Future<List<Address?>?>
Returns an array of Addresses that attempt to describe the named location, which may be a place name such as "Dalvik, Iceland", an address such as "1600 Amphitheatre Parkway, Mountain View, CA", an airport code such as "SFO", and so forth.
getFromLocationPreAndroidApi33(double latitude, double longitude, int maxResults) Future<List<Address?>?>
Provides an array of Addresses that attempt to describe the area immediately surrounding the given latitude and longitude.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pigeon_copy() Geocoder
Instantiates and returns a functionally identical object to oneself.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isPresent({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager}) Future<bool>
Returns true if there is a geocoder implementation present on the device that may return results.
pigeon_setUpMessageHandlers({bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Geocoder pigeon_newInstance()?}) → void