GeographicBounds class

Geographical bounds describing a geographic box.

Constructors

GeographicBounds({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required double lowerLeftLatitude, required double lowerLeftLongitude, required double upperRightLatitude, required double upperRightLongitude})
factory
GeographicBounds.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required double lowerLeftLatitude, required double lowerLeftLongitude, required double upperRightLatitude, required double upperRightLongitude})
Constructs GeographicBounds without creating the associated native object.
GeographicBounds.pigeon_new({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required double lowerLeftLatitude, required double lowerLeftLongitude, required double upperRightLatitude, required double upperRightLongitude})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lowerLeftLatitude → double
final
lowerLeftLongitude → double
final
pigeon_binaryMessenger → BinaryMessenger?
Sends and receives binary data across the Flutter platform barrier.
finalinherited
pigeon_instanceManager → PigeonInstanceManager
Maintains instances stored to communicate with native language objects.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upperRightLatitude → double
final
upperRightLongitude → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pigeon_copy() → GeographicBounds
Instantiates and returns a functionally identical object to oneself.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

pigeon_setUpMessageHandlers({bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, GeographicBounds pigeon_newInstance(double lowerLeftLatitude, double lowerLeftLongitude, double upperRightLatitude, double upperRightLongitude)?}) → void