GeographicBounds.pigeon_detached constructor

  1. @protected
GeographicBounds.pigeon_detached({
  1. BinaryMessenger? pigeon_binaryMessenger,
  2. PigeonInstanceManager? pigeon_instanceManager,
  3. required double lowerLeftLatitude,
  4. required double lowerLeftLongitude,
  5. required double upperRightLatitude,
  6. required double upperRightLongitude,
})

Constructs GeographicBounds without creating the associated native object.

This should only be used by subclasses created by this library or to create copies for an PigeonInstanceManager.

Implementation

@protected
GeographicBounds.pigeon_detached({
  super.pigeon_binaryMessenger,
  super.pigeon_instanceManager,
  required this.lowerLeftLatitude,
  required this.lowerLeftLongitude,
  required this.upperRightLatitude,
  required this.upperRightLongitude,
});