pigeon_copy method

  1. @override
GeographicBounds pigeon_copy()

Instantiates and returns a functionally identical object to oneself.

Outside of tests, this method should only ever be called by PigeonInstanceManager.

Subclasses should always override their parent's implementation of this method.

Implementation

@override
GeographicBounds pigeon_copy() {
  return GeographicBounds.pigeon_detached(
    pigeon_binaryMessenger: pigeon_binaryMessenger,
    pigeon_instanceManager: pigeon_instanceManager,
    lowerLeftLatitude: lowerLeftLatitude,
    lowerLeftLongitude: lowerLeftLongitude,
    upperRightLatitude: upperRightLatitude,
    upperRightLongitude: upperRightLongitude,
  );
}