Geocoding class abstract

Interface for a platform implementation of a Geocoding instance.

Platform implementations should extend this class rather than implement it as geocoding package does not consider newly added methods to be breaking changes. Extending this class (using extends) ensures that the subclass will get the default implementation, while platform implementations that implements this interface will be broken by newly added Geocoding methods.

Inheritance
  • Object
  • PlatformInterface
  • Geocoding
Implementers

Constructors

Geocoding(GeocodingCreationParams params)
Creates a new PlatformWebViewController
factory
Geocoding.implementation(GeocodingCreationParams params)
Used by the platform implementation to create a new Geocoding.

Properties

hashCode int
The hash code for this object.
no setterinherited
params → GeocodingCreationParams
The parameters used to initialize the Geocoding instance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isPresent() Future<bool>
Returns true if there is a geocoder implementation present that may return results. If true, there is still no guarantee that any individual geocoding attempt will succeed.
locationFromAddress(String address, {Locale? locale}) Future<List<Location>>
Returns a list of Location instances found for the supplied address.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
placemarkFromAddress(String address, {Locale? locale}) Future<List<Placemark>>
Returns a list of Placemark instances found for the supplied address.
placemarkFromCoordinates(double latitude, double longitude, {Locale? locale}) Future<List<Placemark>>
Returns a list of Placemark instances found for the supplied coordinates.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited