GeocodingAndroid class

An implementation of the Geocoding interface for the Android platforms.

Inheritance

Constructors

GeocodingAndroid(GeocodingCreationParams params)
Creates a GeocodingDarwin.

Properties

hashCode int
The hash code for this object.
no setterinherited
params → GeocodingCreationParams
The parameters used to initialize the Geocoding instance.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isPresent() Future<bool>
Returns true if there is a geocoder implementation present that may return results. If true, there is still no guarantee that any individual geocoding attempt will succeed.
override
locationFromAddress(String address, {Locale? locale}) Future<List<Location>>
Returns a list of Location instances found for the supplied address.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
placemarkFromAddress(String address, {Locale? locale}) Future<List<Placemark>>
Returns a list of Placemark instances found for the supplied address.
override
placemarkFromCoordinates(double latitude, double longitude, {Locale? locale}) Future<List<Placemark>>
Returns a list of Placemark instances found for the supplied coordinates.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited