Address class
A class representing an Address, that is, a set of Strings describing a location.
See https://developer.android.com/reference/android/location/Address.
Constructors
- Address.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager})
- Constructs Address without creating the associated native object.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeon_binaryMessenger → BinaryMessenger?
-
Sends and receives binary data across the Flutter platform barrier.
finalinherited
- pigeon_instanceManager → PigeonInstanceManager
-
Maintains instances stored to communicate with native language objects.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAddressLine(
int index) → Future< String?> - Returns a line of the address numbered by the given index (starting at 0), or null if no such line is present.
-
getAdminArea(
) → Future< String?> - Returns the administrative area name of the address, for example, "CA", or null if it is unknown/
-
getCountryCode(
) → Future< String?> - Returns the country code of the address, for example "US", or null if it is unknown.
-
getCountryName(
) → Future< String?> - Returns the localized country name of the address, for example "Iceland", or null if it is unknown.
-
getFeatureName(
) → Future< String?> - Returns the feature name of the address, for example, "Golden Gate Bridge", or null if it is unknown
-
getLatitude(
) → Future< double?> - Returns the latitude of the address if known.
-
getLocale(
) → Future< Locale> - Returns the Locale associated with this address.
-
getLocality(
) → Future< String?> - Returns the locality of the address, for example "Mountain View", or null if it is unknown.
-
getLongitude(
) → Future< double?> - Returns the longitude of the address if known.
-
getMaxAddressLineIndex(
) → Future< int> - Returns the largest index currently in use to specify an address line.
-
getPhone(
) → Future< String?> - Returns the phone number of the address if known, or null if it is unknown.
-
getPostalCode(
) → Future< String?> - Returns the postal code of the address, for example "94110", or null if it is unknown.
-
getPremises(
) → Future< String?> - Returns the premises of the address, or null if it is unknown.
-
getSubAdminArea(
) → Future< String?> - Returns the sub-administrative area name of the address, for example, "Santa Clara County", or null if it is unknown
-
getSubLocality(
) → Future< String?> - Returns the sub-locality of the address, or null if it is unknown.
-
getSubThouroughfare(
) → Future< String?> - Returns the sub-thoroughfare name of the address, which may be null.
-
getThouroughfare(
) → Future< String?> - Returns the thoroughfare name of the address, for example, "1600 Ampitheater Parkway", which may be null
-
getUrl(
) → Future< String?> - Returns the public URL for the address if known, or null if it is unknown.
-
hasLatitude(
) → Future< bool> - Returns true if a latitude has been assigned to this Address, false otherwise.
-
hasLongitude(
) → Future< bool> - Returns true if a longitude has been assigned to this Address, false otherwise.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pigeon_copy(
) → Address - Instantiates and returns a functionally identical object to oneself.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pigeon_setUpMessageHandlers(
{bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Address pigeon_newInstance()?}) → void