Locale class
A Locale object represents a specific geographical, political, or cultural
region.
See https://developer.android.com/reference/java/util/Locale.
Constructors
- Locale({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required String identifier})
-
Creates a Locale.
factory
- Locale.pigeon_detached({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager})
- Constructs Locale without creating the associated native object.
- Locale.pigeon_new({BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, required String identifier})
- Creates a Locale.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeon_binaryMessenger → BinaryMessenger?
-
Sends and receives binary data across the Flutter platform barrier.
finalinherited
- pigeon_instanceManager → PigeonInstanceManager
-
Maintains instances stored to communicate with native language objects.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCountry(
) → Future< String> - Returns the country/region code for this locale, which should either be the empty string, an uppercase ISO 3166 2-letter code, or a UN M.49 3-digit code.
-
getISO3Country(
) → Future< String> - If the country matches an ISO 3166-1 alpha-2 code, the corresponding ISO 3166-1 alpha-3 uppercase code is returned.
-
getISO3Language(
) → Future< String> - If the language matches an ISO 639-1 two-letter code, the corresponding ISO 639-2/T three-letter lowercase code is returned.
-
getLanguage(
) → Future< String> - Returns the language code of this Locale.
-
getScript(
) → Future< String> - Returns the script for this locale, which should either be the empty string or an ISO 15924 4-letter script code.
-
getVariant(
) → Future< String> - Returns the variant code for this locale.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pigeon_copy(
) → Locale - Instantiates and returns a functionally identical object to oneself.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pigeon_setUpMessageHandlers(
{bool pigeon_clearHandlers = false, BinaryMessenger? pigeon_binaryMessenger, PigeonInstanceManager? pigeon_instanceManager, Locale pigeon_newInstance()?}) → void