geocoding_android library
Classes
- Geocoding
- Interface for a platform implementation of a Geocoding instance.
- GeocodingAndroid
- An implementation of the Geocoding interface for the Android platforms.
- GeocodingAndroidCreationParams
- Object specifying creation parameters for a GeocodingAndroid instance.
- GeocodingAndroidFactory
-
Implementation of
GeocodingPlatformFactoryfor the Android platform. - Location
- Describes a location on earth represented by geographical coordinates.the
- Placemark
- Defines the parameters that describe a result of the (reserve)geocoding action.